cosmpy.protos.ibc.core.connection package — cosmpy documentation

# cosmpy.protos.ibc.core.connection package

## Subpackages

- cosmpy.protos.ibc.core.connection.v1 package
  - Submodules
  - cosmpy.protos.ibc.core.connection.v1.connection_pb2 module
  - cosmpy.protos.ibc.core.connection.v1.connection_pb2_grpc module
  - cosmpy.protos.ibc.core.connection.v1.genesis_pb2 module
  - cosmpy.protos.ibc.core.connection.v1.genesis_pb2_grpc module
  - cosmpy.protos.ibc.core.connection.v1.query_pb2 module
  - cosmpy.protos.ibc.core.connection.v1.query_pb2_grpc module
  - cosmpy.protos.ibc.core.connection.v1.tx_pb2 module
  - cosmpy.protos.ibc.core.connection.v1.tx_pb2_grpc module
  - Module contents

## Module contents